@@ -18,7 +18,7 @@ class Class(Base):
 
     # don't add here until request/referral process is successfully completed
     students = relationship("User", secondary=student_class_association, back_populates="classesAsStudent")
-    tutors = relationship("User", secondary=tutor_class_association, back_populates="classesAsTutors")
+    tutors = relationship("User", secondary=tutor_class_association, back_populates="classesAsTutor")
 
     def __init__(self, name, teacher):
         self.name = name
